import logging
import os

from django.conf import settings
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.utils import simplejson

logger = logging.getLogger("django_jasmine")


def run_tests(request, path):
    """Run the jasmine tests and render index.html"""
    full_path = os.path.join(settings.JASMINE_TEST_DIRECTORY, path)
    full_path, directories, files = os.walk(full_path).next()
    for file_name in os.walk(os.path.join(full_path, 'spec')).next()[2]:
        files.append(file_name)

    suite = {}

    # defaults
    suite['js_files'] = []
    suite['static_files'] = []

    # load files.json if present
    if 'files.json' in files:
        file = open(os.path.join(full_path, 'files.json'), 'r')
        json = file.read()
        try:
            json = simplejson.loads(json)
        except ValueError:
            logger.info("You might have a syntax error in your files.json, "
                "like a surplus comma")
            # Trick to call back the django handler500, couldn't find a way to
            # customize the Exception Type field in the debug Traceback
            json = simplejson.loads(json)
        suite.update(json)

    data = {
        'files': [path + file for file in files if file.endswith('js')],
        'suite': suite,
    }

    return render_to_response('jasmine/index.html', data,
        context_instance=RequestContext(request))



#!/usr/bin/env python
from distutils.core import setup

setup(
    name='django-jasmine',
    version='0.3',
    description='Jasmine Javascript testing integration for Django.',
    long_description=open('README.rst').read(),
    author='Jonathan McCoy',
    author_email='modelsolutions@gmail.com',
    maintainer='Adrien Lemaire',
    maintainer_email='adrien.lemaire@gmail.com',
    url='https://github.com/Fandekasp/django-jasmine',
    packages=[
        'django_jasmine',
    ],
    package_data={
        'django_jasmine': ['templates/jasmine/*', 'media/jasmine-1.1.0.rc1/*'],
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: JavaScript',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Testing',
    ],
)



import os

from django.conf.urls.defaults import *
from django.conf import settings

from views import run_tests

static_root = os.path.join(os.path.dirname(__file__), 'static')


urlpatterns = patterns('django.views',
    url(r'^tests/(?P<path>.*)$', 'static.serve', {
        'document_root': os.path.join(settings.JASMINE_TEST_DIRECTORY, "spec"),
    }, name='jasmine_test'),
    url(r'^src/(?P<path>.*)$', 'static.serve', {
        'document_root': os.path.join(settings.JASMINE_TEST_DIRECTORY, "src"),
    }, name='jasmine_src'),
    url(r'^fixtures/(?P<path>.*)$', 'static.serve', {
        'document_root': os.path.join(
            settings.JASMINE_TEST_DIRECTORY, "fixtures",
        ),
    }, name='jasmine_fixtures'),
    url('^(?P<path>.*)$', run_tests, name='jasmine_test_overview'),
)
